@@ -23,13 +23,13 @@
 #include "gconf-editor-window.h"
 #include "gconf-tree-model.h"
 #include "gconf-list-model.h"
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 
 static GSList *editor_windows = NULL;
 
 static void
-gconf_editor_application_window_destroyed (GtkObject *window)
+gconf_editor_application_window_destroyed (GtkWidget *window)
 {
 	editor_windows = g_slist_remove (editor_windows, window);
 
@@ -48,30 +48,20 @@ gconf_editor_application_create_editor_window (int type)
 	gconfwindow = GCONF_EDITOR_WINDOW (window);
 
 	if (gconfwindow->client == NULL) {
-		gconf_editor_application_window_destroyed (GTK_OBJECT (window));
+		gconf_editor_application_window_destroyed (window);
 		return NULL;
 	}
 
 	gconf_tree_model_set_client (GCONF_TREE_MODEL (gconfwindow->tree_model), gconfwindow->client);
 	gconf_list_model_set_client (GCONF_LIST_MODEL (gconfwindow->list_model), gconfwindow->client);
 
-	if (!gconf_util_can_edit_defaults ()) {
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (gconfwindow->ui_manager, "/GConfKeyPopupMenu/DefaultKey"),
-					  FALSE);
+	if (!gconf_util_can_edit_defaults ())
 		gtk_action_set_sensitive (gtk_ui_manager_get_action (gconfwindow->ui_manager, "/GConfEditorMenu/FileMenu/NewDefaultsWindow"),
 					  FALSE);
-	} else if (gconfwindow->type == GCONF_EDITOR_WINDOW_TYPE_DEFAULTS)
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (gconfwindow->ui_manager, "/GConfKeyPopupMenu/DefaultKey"),
-					  FALSE);
 
-	if (!gconf_util_can_edit_mandatory ()) {
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (gconfwindow->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"),
-					  FALSE);
+	if (!gconf_util_can_edit_mandatory ())
 		gtk_action_set_sensitive (gtk_ui_manager_get_action (gconfwindow->ui_manager, "/GConfEditorMenu/FileMenu/NewMandatoryWindow"),
 					  FALSE);
-	} else if (gconfwindow->type == GCONF_EDITOR_WINDOW_TYPE_MANDATORY)
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (gconfwindow->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"),
-					  FALSE);
 	
 	g_signal_connect (window, "destroy",
 			  G_CALLBACK (gconf_editor_application_window_destroyed), NULL);
