@@ -85,7 +85,7 @@ static void
 gconf_editor_window_close_window (GtkAction *action G_GNUC_UNUSED,
 				  GtkWidget *window)
 {
-	gtk_object_destroy (GTK_OBJECT (window));
+	gtk_widget_destroy (window);
 }
 
 void
@@ -1288,18 +1288,6 @@ gconf_editor_window_setup_ui_prefs_handler (GConfEditorWindow *window)
 	g_object_unref (client);
 }
 
-static void
-gconf_editor_window_style_set (GtkWidget *widget, GtkStyle *prev_style, GtkWidget *text_view)
-{
-	GtkStyle *style;
-
-	style = gtk_widget_get_style (widget);
-	gtk_widget_modify_base (text_view, GTK_STATE_NORMAL,
-				&style->bg[GTK_STATE_NORMAL]);
-	gtk_widget_modify_text (text_view, GTK_STATE_NORMAL,
-				&style->fg[GTK_STATE_NORMAL]);
-}
-
 void
 gconf_editor_window_expand_first (GConfEditorWindow *window)
 {
@@ -1440,9 +1428,8 @@ gconf_editor_window_class_init (GConfEditorWindowClass *klass)
 }
 
 static void
-tree_view_style_set_cb (GtkWidget *widget,
-                        GtkStyle *previous_style,
-                        GObject *cell)
+tree_view_style_updated_cb (GtkWidget *widget,
+                            GObject *cell)
 {
         GdkPixbuf *folder_open = NULL, *folder_closed = NULL;
         int w, h;
@@ -1483,6 +1470,7 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	GtkWidget *details_frame, *alignment, *table, *label, *text_view, *image;
 	gchar *markup;
 	GError *error;
+        GdkRGBA bg;
 	
 	gtk_window_set_default_size (GTK_WINDOW (window), 700, 550);
 
@@ -1568,7 +1556,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	column = gtk_tree_view_column_new ();
 
 	cell = gtk_cell_renderer_pixbuf_new ();
-        g_signal_connect (window->tree_view, "style-set", G_CALLBACK (tree_view_style_set_cb), cell);
+        g_signal_connect (window->tree_view, "style-updated",
+                          G_CALLBACK (tree_view_style_updated_cb), cell);
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
 	cell = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, cell, TRUE);
@@ -1753,12 +1742,18 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	window->long_desc_buffer = gtk_text_buffer_new (NULL);
 	gtk_text_buffer_set_text (window->long_desc_buffer, _("(None)"), -1);	
 	text_view = gtk_text_view_new_with_buffer (window->long_desc_buffer);
-	g_signal_connect (window, "style_set",
-			  G_CALLBACK (gconf_editor_window_style_set),
-			  text_view);
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (text_view), GTK_WRAP_WORD);
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), FALSE);
-	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+
+        gtk_style_context_get_background_color (gtk_widget_get_style_context (GTK_WIDGET (window)),
+                                                0, &bg);
+        gtk_widget_override_background_color (text_view, 0, &bg);
+
+        gtk_style_context_get_background_color (gtk_widget_get_style_context (GTK_WIDGET (window)),
+                                                GTK_STATE_FLAG_SELECTED, &bg);
+        gtk_widget_override_background_color (text_view, GTK_STATE_FLAG_SELECTED, &bg);
+
+        scrolled_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
